pytilities.geometry.discreterectangle — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry.discreterectangle

class `pytilities.geometry.discreterectangle.` `DiscreteRectangle`

  A rectangle with discrete coordinates.

  This rectangle greatly resembles Rectangle, but works with a discrete coordinate space. All results are floored.

  `height`

    Read-write, height of the rectangle

  `width`

    Read-write, width of the rectangle

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »